# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from collections import OrderedDict
import functools
import re
from typing import (
    Dict,
    Mapping,
    MutableMapping,
    MutableSequence,
    Optional,
    Sequence,
    Tuple,
    Type,
    Union,
)

from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.api_core.client_options import ClientOptions
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.talent_v4beta1 import gapic_version as package_version

try:
    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
except AttributeError:  # pragma: NO COVER
    OptionalRetry = Union[retries.Retry, object]  # type: ignore

from google.api_core import operation  # type: ignore
from google.api_core import operation_async  # type: ignore
from google.longrunning import operations_pb2
from google.protobuf import timestamp_pb2  # type: ignore

from google.cloud.talent_v4beta1.services.job_service import pagers
from google.cloud.talent_v4beta1.types import common
from google.cloud.talent_v4beta1.types import job
from google.cloud.talent_v4beta1.types import job as gct_job
from google.cloud.talent_v4beta1.types import job_service

from .client import JobServiceClient
from .transports.base import DEFAULT_CLIENT_INFO, JobServiceTransport
from .transports.grpc_asyncio import JobServiceGrpcAsyncIOTransport


class JobServiceAsyncClient:
    """A service handles job management, including job CRUD,
    enumeration and search.
    """

    _client: JobServiceClient

    DEFAULT_ENDPOINT = JobServiceClient.DEFAULT_ENDPOINT
    DEFAULT_MTLS_ENDPOINT = JobServiceClient.DEFAULT_MTLS_ENDPOINT

    company_path = staticmethod(JobServiceClient.company_path)
    parse_company_path = staticmethod(JobServiceClient.parse_company_path)
    job_path = staticmethod(JobServiceClient.job_path)
    parse_job_path = staticmethod(JobServiceClient.parse_job_path)
    common_billing_account_path = staticmethod(
        JobServiceClient.common_billing_account_path
    )
    parse_common_billing_account_path = staticmethod(
        JobServiceClient.parse_common_billing_account_path
    )
    common_folder_path = staticmethod(JobServiceClient.common_folder_path)
    parse_common_folder_path = staticmethod(JobServiceClient.parse_common_folder_path)
    common_organization_path = staticmethod(JobServiceClient.common_organization_path)
    parse_common_organization_path = staticmethod(
        JobServiceClient.parse_common_organization_path
    )
    common_project_path = staticmethod(JobServiceClient.common_project_path)
    parse_common_project_path = staticmethod(JobServiceClient.parse_common_project_path)
    common_location_path = staticmethod(JobServiceClient.common_location_path)
    parse_common_location_path = staticmethod(
        JobServiceClient.parse_common_location_path
    )

    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            info.

        Args:
            info (dict): The service account private key info.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            JobServiceAsyncClient: The constructed client.
        """
        return JobServiceClient.from_service_account_info.__func__(JobServiceAsyncClient, info, *args, **kwargs)  # type: ignore

    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            JobServiceAsyncClient: The constructed client.
        """
        return JobServiceClient.from_service_account_file.__func__(JobServiceAsyncClient, filename, *args, **kwargs)  # type: ignore

    from_service_account_json = from_service_account_file

    @classmethod
    def get_mtls_endpoint_and_cert_source(
        cls, client_options: Optional[ClientOptions] = None
    ):
        """Return the API endpoint and client cert source for mutual TLS.

        The client cert source is determined in the following order:
        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
        client cert source is None.
        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
        default client cert source exists, use the default one; otherwise the client cert
        source is None.

        The API endpoint is determined in the following order:
        (1) if `client_options.api_endpoint` if provided, use the provided one.
        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
        default mTLS endpoint; if the environment variabel is "never", use the default API
        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
        use the default API endpoint.

        More details can be found at https://google.aip.dev/auth/4114.

        Args:
            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                client. Only the `api_endpoint` and `client_cert_source` properties may be used
                in this method.

        Returns:
            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
                client cert source to use.

        Raises:
            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
        """
        return JobServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore

    @property
    def transport(self) -> JobServiceTransport:
        """Returns the transport used by the client instance.

        Returns:
            JobServiceTransport: The transport used by the client instance.
        """
        return self._client.transport

    get_transport_class = functools.partial(
        type(JobServiceClient).get_transport_class, type(JobServiceClient)
    )

    def __init__(
        self,
        *,
        credentials: Optional[ga_credentials.Credentials] = None,
        transport: Union[str, JobServiceTransport] = "grpc_asyncio",
        client_options: Optional[ClientOptions] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
    ) -> None:
        """Instantiates the job service client.

        Args:
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            transport (Union[str, ~.JobServiceTransport]): The
                transport to use. If set to None, a transport is chosen
                automatically.
            client_options (ClientOptions): Custom options for the client. It
                won't take effect if a ``transport`` instance is provided.
                (1) The ``api_endpoint`` property can be used to override the
                default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
                environment variable can also be used to override the endpoint:
                "always" (always use the default mTLS endpoint), "never" (always
                use the default regular endpoint) and "auto" (auto switch to the
                default mTLS endpoint if client certificate is present, this is
                the default value). However, the ``api_endpoint`` property takes
                precedence if provided.
                (2) If GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
                is "true", then the ``client_cert_source`` property can be used
                to provide client certificate for mutual TLS transport. If
                not provided, the default SSL client certificate will be used if
                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
                set, no client certificate will be used.

        Raises:
            google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                creation failed for any reason.
        """
        self._client = JobServiceClient(
            credentials=credentials,
            transport=transport,
            client_options=client_options,
            client_info=client_info,
        )

    async def create_job(
        self,
        request: Optional[Union[job_service.CreateJobRequest, dict]] = None,
        *,
        parent: Optional[str] = None,
        job: Optional[gct_job.Job] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> gct_job.Job:
        r"""Creates a new job.
        Typically, the job becomes searchable within 10 seconds,
        but it may take up to 5 minutes.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import talent_v4beta1

            async def sample_create_job():
                # Create a client
                client = talent_v4beta1.JobServiceAsyncClient()

                # Initialize request argument(s)
                job = talent_v4beta1.Job()
                job.company = "company_value"
                job.requisition_id = "requisition_id_value"
                job.title = "title_value"
                job.description = "description_value"

                request = talent_v4beta1.CreateJobRequest(
                    parent="parent_value",
                    job=job,
                )

                # Make the request
                response = await client.create_job(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.talent_v4beta1.types.CreateJobRequest, dict]]):
                The request object. Create job request.
            parent (:class:`str`):
                Required. The resource name of the tenant under which
                the job is created.

                The format is
                "projects/{project_id}/tenants/{tenant_id}". For
                example, "projects/foo/tenant/bar". If tenant id is
                unspecified a default tenant is created. For example,
                "projects/foo".

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            job (:class:`google.cloud.talent_v4beta1.types.Job`):
                Required. The Job to be created.
                This corresponds to the ``job`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.talent_v4beta1.types.Job:
                A Job resource represents a job posting (also referred to as a "job listing"
                   or "job requisition"). A job belongs to a
                   [Company][google.cloud.talent.v4beta1.Company], which
                   is the hiring entity responsible for the job.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent, job])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = job_service.CreateJobRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent
        if job is not None:
            request.job = job

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.create_job,
            default_timeout=30.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def batch_create_jobs(
        self,
        request: Optional[Union[job_service.BatchCreateJobsRequest, dict]] = None,
        *,
        parent: Optional[str] = None,
        jobs: Optional[MutableSequence[job.Job]] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> operation_async.AsyncOperation:
        r"""Begins executing a batch create jobs operation.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import talent_v4beta1

            async def sample_batch_create_jobs():
                # Create a client
                client = talent_v4beta1.JobServiceAsyncClient()

                # Initialize request argument(s)
                jobs = talent_v4beta1.Job()
                jobs.company = "company_value"
                jobs.requisition_id = "requisition_id_value"
                jobs.title = "title_value"
                jobs.description = "description_value"

                request = talent_v4beta1.BatchCreateJobsRequest(
                    parent="parent_value",
                    jobs=jobs,
                )

                # Make the request
                operation = client.batch_create_jobs(request=request)

                print("Waiting for operation to complete...")

                response = (await operation).result()

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.talent_v4beta1.types.BatchCreateJobsRequest, dict]]):
                The request object. Request to create a batch of jobs.
            parent (:class:`str`):
                Required. The resource name of the tenant under which
                the job is created.

                The format is
                "projects/{project_id}/tenants/{tenant_id}". For
                example, "projects/foo/tenant/bar". If tenant id is
                unspecified, a default tenant is created. For example,
                "projects/foo".

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            jobs (:class:`MutableSequence[google.cloud.talent_v4beta1.types.Job]`):
                Required. The jobs to be created.
                This corresponds to the ``jobs`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.api_core.operation_async.AsyncOperation:
                An object representing a long-running operation.

                The result type for the operation will be :class:`google.cloud.talent_v4beta1.types.JobOperationResult` The result of [JobService.BatchCreateJobs][google.cloud.talent.v4beta1.JobService.BatchCreateJobs] or
                   [JobService.BatchUpdateJobs][google.cloud.talent.v4beta1.JobService.BatchUpdateJobs]
                   APIs. It's used to replace
                   [google.longrunning.Operation.response][google.longrunning.Operation.response]
                   in case of success.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent, jobs])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = job_service.BatchCreateJobsRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent
        if jobs:
            request.jobs.extend(jobs)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.batch_create_jobs,
            default_timeout=30.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Wrap the response in an operation future.
        response = operation_async.from_gapic(
            response,
            self._client._transport.operations_client,
            job_service.JobOperationResult,
            metadata_type=common.BatchOperationMetadata,
        )

        # Done; return the response.
        return response

    async def get_job(
        self,
        request: Optional[Union[job_service.GetJobRequest, dict]] = None,
        *,
        name: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> job.Job:
        r"""Retrieves the specified job, whose status is OPEN or
        recently EXPIRED within the last 90 days.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import talent_v4beta1

            async def sample_get_job():
                # Create a client
                client = talent_v4beta1.JobServiceAsyncClient()

                # Initialize request argument(s)
                request = talent_v4beta1.GetJobRequest(
                    name="name_value",
                )

                # Make the request
                response = await client.get_job(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.talent_v4beta1.types.GetJobRequest, dict]]):
                The request object. Get job request.
            name (:class:`str`):
                Required. The resource name of the job to retrieve.

                The format is
                "projects/{project_id}/tenants/{tenant_id}/jobs/{job_id}".
                For example, "projects/foo/tenants/bar/jobs/baz".

                If tenant id is unspecified, the default tenant is used.
                For example, "projects/foo/jobs/bar".

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.talent_v4beta1.types.Job:
                A Job resource represents a job posting (also referred to as a "job listing"
                   or "job requisition"). A job belongs to a
                   [Company][google.cloud.talent.v4beta1.Company], which
                   is the hiring entity responsible for the job.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = job_service.GetJobRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.get_job,
            default_retry=retries.Retry(
                initial=0.1,
                maximum=60.0,
                multiplier=1.3,
                predicate=retries.if_exception_type(
                    core_exceptions.DeadlineExceeded,
                    core_exceptions.ServiceUnavailable,
                ),
                deadline=30.0,
            ),
            default_timeout=30.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def update_job(
        self,
        request: Optional[Union[job_service.UpdateJobRequest, dict]] = None,
        *,
        job: Optional[gct_job.Job] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> gct_job.Job:
        r"""Updates specified job.
        Typically, updated contents become visible in search
        results within 10 seconds, but it may take up to 5
        minutes.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import talent_v4beta1

            async def sample_update_job():
                # Create a client
                client = talent_v4beta1.JobServiceAsyncClient()

                # Initialize request argument(s)
                job = talent_v4beta1.Job()
                job.company = "company_value"
                job.requisition_id = "requisition_id_value"
                job.title = "title_value"
                job.description = "description_value"

                request = talent_v4beta1.UpdateJobRequest(
                    job=job,
                )

                # Make the request
                response = await client.update_job(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.talent_v4beta1.types.UpdateJobRequest, dict]]):
                The request object. Update job request.
            job (:class:`google.cloud.talent_v4beta1.types.Job`):
                Required. The Job to be updated.
                This corresponds to the ``job`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.talent_v4beta1.types.Job:
                A Job resource represents a job posting (also referred to as a "job listing"
                   or "job requisition"). A job belongs to a
                   [Company][google.cloud.talent.v4beta1.Company], which
                   is the hiring entity responsible for the job.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([job])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = job_service.UpdateJobRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if job is not None:
            request.job = job

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.update_job,
            default_timeout=30.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("job.name", request.job.name),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def batch_update_jobs(
        self,
        request: Optional[Union[job_service.BatchUpdateJobsRequest, dict]] = None,
        *,
        parent: Optional[str] = None,
        jobs: Optional[MutableSequence[job.Job]] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> operation_async.AsyncOperation:
        r"""Begins executing a batch update jobs operation.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import talent_v4beta1

            async def sample_batch_update_jobs():
                # Create a client
                client = talent_v4beta1.JobServiceAsyncClient()

                # Initialize request argument(s)
                jobs = talent_v4beta1.Job()
                jobs.company = "company_value"
                jobs.requisition_id = "requisition_id_value"
                jobs.title = "title_value"
                jobs.description = "description_value"

                request = talent_v4beta1.BatchUpdateJobsRequest(
                    parent="parent_value",
                    jobs=jobs,
                )

                # Make the request
                operation = client.batch_update_jobs(request=request)

                print("Waiting for operation to complete...")

                response = (await operation).result()

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.talent_v4beta1.types.BatchUpdateJobsRequest, dict]]):
                The request object. Request to update a batch of jobs.
            parent (:class:`str`):
                Required. The resource name of the tenant under which
                the job is created.

                The format is
                "projects/{project_id}/tenants/{tenant_id}". For
                example, "projects/foo/tenant/bar". If tenant id is
                unspecified, a default tenant is created. For example,
                "projects/foo".

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            jobs (:class:`MutableSequence[google.cloud.talent_v4beta1.types.Job]`):
                Required. The jobs to be updated.
                This corresponds to the ``jobs`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.api_core.operation_async.AsyncOperation:
                An object representing a long-running operation.

                The result type for the operation will be :class:`google.cloud.talent_v4beta1.types.JobOperationResult` The result of [JobService.BatchCreateJobs][google.cloud.talent.v4beta1.JobService.BatchCreateJobs] or
                   [JobService.BatchUpdateJobs][google.cloud.talent.v4beta1.JobService.BatchUpdateJobs]
                   APIs. It's used to replace
                   [google.longrunning.Operation.response][google.longrunning.Operation.response]
                   in case of success.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent, jobs])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = job_service.BatchUpdateJobsRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent
        if jobs:
            request.jobs.extend(jobs)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.batch_update_jobs,
            default_timeout=30.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Wrap the response in an operation future.
        response = operation_async.from_gapic(
            response,
            self._client._transport.operations_client,
            job_service.JobOperationResult,
            metadata_type=common.BatchOperationMetadata,
        )

        # Done; return the response.
        return response

    async def delete_job(
        self,
        request: Optional[Union[job_service.DeleteJobRequest, dict]] = None,
        *,
        name: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> None:
        r"""Deletes the specified job.
        Typically, the job becomes unsearchable within 10
        seconds, but it may take up to 5 minutes.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import talent_v4beta1

            async def sample_delete_job():
                # Create a client
                client = talent_v4beta1.JobServiceAsyncClient()

                # Initialize request argument(s)
                request = talent_v4beta1.DeleteJobRequest(
                    name="name_value",
                )

                # Make the request
                await client.delete_job(request=request)

        Args:
            request (Optional[Union[google.cloud.talent_v4beta1.types.DeleteJobRequest, dict]]):
                The request object. Delete job request.
            name (:class:`str`):
                Required. The resource name of the job to be deleted.

                The format is
                "projects/{project_id}/tenants/{tenant_id}/jobs/{job_id}".
                For example, "projects/foo/tenants/bar/jobs/baz".

                If tenant id is unspecified, the default tenant is used.
                For example, "projects/foo/jobs/bar".

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = job_service.DeleteJobRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.delete_job,
            default_retry=retries.Retry(
                initial=0.1,
                maximum=60.0,
                multiplier=1.3,
                predicate=retries.if_exception_type(
                    core_exceptions.DeadlineExceeded,
                    core_exceptions.ServiceUnavailable,
                ),
                deadline=30.0,
            ),
            default_timeout=30.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

    async def batch_delete_jobs(
        self,
        request: Optional[Union[job_service.BatchDeleteJobsRequest, dict]] = None,
        *,
        parent: Optional[str] = None,
        filter: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> None:
        r"""Deletes a list of [Job][google.cloud.talent.v4beta1.Job]s by
        filter.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import talent_v4beta1

            async def sample_batch_delete_jobs():
                # Create a client
                client = talent_v4beta1.JobServiceAsyncClient()

                # Initialize request argument(s)
                request = talent_v4beta1.BatchDeleteJobsRequest(
                    parent="parent_value",
                    filter="filter_value",
                )

                # Make the request
                await client.batch_delete_jobs(request=request)

        Args:
            request (Optional[Union[google.cloud.talent_v4beta1.types.BatchDeleteJobsRequest, dict]]):
                The request object. Batch delete jobs request.
            parent (:class:`str`):
                Required. The resource name of the tenant under which
                the job is created.

                The format is
                "projects/{project_id}/tenants/{tenant_id}". For
                example, "projects/foo/tenant/bar". If tenant id is
                unspecified, a default tenant is created. For example,
                "projects/foo".

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            filter (:class:`str`):
                Required. The filter string specifies the jobs to be
                deleted.

                Supported operator: =, AND

                The fields eligible for filtering are:

                -  ``companyName`` (Required)
                -  ``requisitionId`` (Required)

                Sample Query: companyName = "projects/foo/companies/bar"
                AND requisitionId = "req-1"

                This corresponds to the ``filter`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent, filter])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = job_service.BatchDeleteJobsRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent
        if filter is not None:
            request.filter = filter

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.batch_delete_jobs,
            default_timeout=30.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

    async def list_jobs(
        self,
        request: Optional[Union[job_service.ListJobsRequest, dict]] = None,
        *,
        parent: Optional[str] = None,
        filter: Optional[str] = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> pagers.ListJobsAsyncPager:
        r"""Lists jobs by filter.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import talent_v4beta1

            async def sample_list_jobs():
                # Create a client
                client = talent_v4beta1.JobServiceAsyncClient()

                # Initialize request argument(s)
                request = talent_v4beta1.ListJobsRequest(
                    parent="parent_value",
                    filter="filter_value",
                )

                # Make the request
                page_result = client.list_jobs(request=request)

                # Handle the response
                async for response in page_result:
                    print(response)

        Args:
            request (Optional[Union[google.cloud.talent_v4beta1.types.ListJobsRequest, dict]]):
                The request object. List jobs request.
            parent (:class:`str`):
                Required. The resource name of the tenant under which
                the job is created.

                The format is
                "projects/{project_id}/tenants/{tenant_id}". For
                example, "projects/foo/tenant/bar". If tenant id is
                unspecified, a default tenant is created. For example,
                "projects/foo".

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            filter (:class:`str`):
                Required. The filter string specifies the jobs to be
                enumerated.

                Supported operator: =, AND

                The fields eligible for filtering are:

                -  ``companyName``
                -  ``requisitionId``
                -  ``status`` Available values: OPEN, EXPIRED, ALL.
                   Defaults to OPEN if no value is specified.

                At least one of ``companyName`` and ``requisitionId``
                must present or an INVALID_ARGUMENT error is thrown.

                Sample Query:

                -  companyName =
                   "projects/foo/tenants/bar/companies/baz"
                -  companyName =
                   "projects/foo/tenants/bar/companies/baz" AND
                   requisitionId = "req-1"
                -  companyName =
                   "projects/foo/tenants/bar/companies/baz" AND status =
                   "EXPIRED"
                -  requisitionId = "req-1"
                -  requisitionId = "req-1" AND status = "EXPIRED"

                This corresponds to the ``filter`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.talent_v4beta1.services.job_service.pagers.ListJobsAsyncPager:
                List jobs response.
                Iterating over this object will yield
                results and resolve additional pages
                automatically.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent, filter])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = job_service.ListJobsRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent
        if filter is not None:
            request.filter = filter

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.list_jobs,
            default_retry=retries.Retry(
                initial=0.1,
                maximum=60.0,
                multiplier=1.3,
                predicate=retries.if_exception_type(
                    core_exceptions.DeadlineExceeded,
                    core_exceptions.ServiceUnavailable,
                ),
                deadline=30.0,
            ),
            default_timeout=30.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # This method is paged; wrap the response in a pager, which provides
        # an `__aiter__` convenience method.
        response = pagers.ListJobsAsyncPager(
            method=rpc,
            request=request,
            response=response,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def search_jobs(
        self,
        request: Optional[Union[job_service.SearchJobsRequest, dict]] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> pagers.SearchJobsAsyncPager:
        r"""Searches for jobs using the provided
        [SearchJobsRequest][google.cloud.talent.v4beta1.SearchJobsRequest].

        This call constrains the
        [visibility][google.cloud.talent.v4beta1.Job.visibility] of jobs
        present in the database, and only returns jobs that the caller
        has permission to search against.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import talent_v4beta1

            async def sample_search_jobs():
                # Create a client
                client = talent_v4beta1.JobServiceAsyncClient()

                # Initialize request argument(s)
                request = talent_v4beta1.SearchJobsRequest(
                    parent="parent_value",
                )

                # Make the request
                page_result = client.search_jobs(request=request)

                # Handle the response
                async for response in page_result:
                    print(response)

        Args:
            request (Optional[Union[google.cloud.talent_v4beta1.types.SearchJobsRequest, dict]]):
                The request object. The Request body of the `SearchJobs`
                call.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.talent_v4beta1.services.job_service.pagers.SearchJobsAsyncPager:
                Response for SearchJob method.
                Iterating over this object will yield
                results and resolve additional pages
                automatically.

        """
        # Create or coerce a protobuf request object.
        request = job_service.SearchJobsRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.search_jobs,
            default_timeout=30.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # This method is paged; wrap the response in a pager, which provides
        # an `__aiter__` convenience method.
        response = pagers.SearchJobsAsyncPager(
            method=rpc,
            request=request,
            response=response,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def search_jobs_for_alert(
        self,
        request: Optional[Union[job_service.SearchJobsRequest, dict]] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> pagers.SearchJobsForAlertAsyncPager:
        r"""Searches for jobs using the provided
        [SearchJobsRequest][google.cloud.talent.v4beta1.SearchJobsRequest].

        This API call is intended for the use case of targeting passive
        job seekers (for example, job seekers who have signed up to
        receive email alerts about potential job opportunities), and has
        different algorithmic adjustments that are targeted to passive
        job seekers.

        This call constrains the
        [visibility][google.cloud.talent.v4beta1.Job.visibility] of jobs
        present in the database, and only returns jobs the caller has
        permission to search against.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import talent_v4beta1

            async def sample_search_jobs_for_alert():
                # Create a client
                client = talent_v4beta1.JobServiceAsyncClient()

                # Initialize request argument(s)
                request = talent_v4beta1.SearchJobsRequest(
                    parent="parent_value",
                )

                # Make the request
                page_result = client.search_jobs_for_alert(request=request)

                # Handle the response
                async for response in page_result:
                    print(response)

        Args:
            request (Optional[Union[google.cloud.talent_v4beta1.types.SearchJobsRequest, dict]]):
                The request object. The Request body of the `SearchJobs`
                call.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.talent_v4beta1.services.job_service.pagers.SearchJobsForAlertAsyncPager:
                Response for SearchJob method.
                Iterating over this object will yield
                results and resolve additional pages
                automatically.

        """
        # Create or coerce a protobuf request object.
        request = job_service.SearchJobsRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.search_jobs_for_alert,
            default_timeout=30.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # This method is paged; wrap the response in a pager, which provides
        # an `__aiter__` convenience method.
        response = pagers.SearchJobsForAlertAsyncPager(
            method=rpc,
            request=request,
            response=response,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def get_operation(
        self,
        request: Optional[operations_pb2.GetOperationRequest] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> operations_pb2.Operation:
        r"""Gets the latest state of a long-running operation.

        Args:
            request (:class:`~.operations_pb2.GetOperationRequest`):
                The request object. Request message for
                `GetOperation` method.
            retry (google.api_core.retry.Retry): Designation of what errors,
                    if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        Returns:
            ~.operations_pb2.Operation:
                An ``Operation`` object.
        """
        # Create or coerce a protobuf request object.
        # The request isn't a proto-plus wrapped type,
        # so it must be constructed via keyword expansion.
        if isinstance(request, dict):
            request = operations_pb2.GetOperationRequest(**request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method.wrap_method(
            self._client._transport.get_operation,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def __aenter__(self):
        return self

    async def __aexit__(self, exc_type, exc, tb):
        await self.transport.close()


DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


__all__ = ("JobServiceAsyncClient",)



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.talent.v4beta1",
    manifest={
        "Tenant",
    },
)


class Tenant(proto.Message):
    r"""A Tenant resource represents a tenant in the service. A
    tenant is a group or entity that shares common access with
    specific privileges for resources like profiles. Customer may
    create multiple tenants to provide data isolation for different
    groups.

    Attributes:
        name (str):
            Required during tenant update.

            The resource name for a tenant. This is generated by the
            service when a tenant is created.

            The format is "projects/{project_id}/tenants/{tenant_id}",
            for example, "projects/foo/tenants/bar".
        external_id (str):
            Required. Client side tenant identifier, used
            to uniquely identify the tenant.
            The maximum number of allowed characters is 255.
        usage_type (google.cloud.talent_v4beta1.types.Tenant.DataUsageType):
            Indicates whether data owned by this tenant may be used to
            provide product improvements across other tenants.

            Defaults behavior is
            [DataUsageType.ISOLATED][google.cloud.talent.v4beta1.Tenant.DataUsageType.ISOLATED]
            if it's unset.
        keyword_searchable_profile_custom_attributes (MutableSequence[str]):
            A list of keys of filterable
            [Profile.custom_attributes][google.cloud.talent.v4beta1.Profile.custom_attributes],
            whose corresponding ``string_values`` are used in keyword
            searches. Profiles with ``string_values`` under these
            specified field keys are returned if any of the values match
            the search keyword. Custom field values with parenthesis,
            brackets and special symbols are not searchable as-is, and
            must be surrounded by quotes.
    """

    class DataUsageType(proto.Enum):
        r"""Enum that represents how user data owned by the tenant is
        used.
        """
        DATA_USAGE_TYPE_UNSPECIFIED = 0
        AGGREGATED = 1
        ISOLATED = 2

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    external_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    usage_type: DataUsageType = proto.Field(
        proto.ENUM,
        number=3,
        enum=DataUsageType,
    )
    keyword_searchable_profile_custom_attributes: MutableSequence[
        str
    ] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.talent.v4",
    manifest={
        "ClientEvent",
        "JobEvent",
    },
)


class ClientEvent(proto.Message):
    r"""An event issued when an end user interacts with the
    application that implements Cloud Talent Solution. Providing
    this information improves the quality of results for the API
    clients, enabling the service to perform optimally. The number
    of events sent must be consistent with other calls, such as job
    searches, issued to the service by the client.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        request_id (str):
            Strongly recommended for the best service experience.

            A unique ID generated in the API responses. It can be found
            in
            [ResponseMetadata.request_id][google.cloud.talent.v4.ResponseMetadata.request_id].
        event_id (str):
            Required. A unique identifier, generated by
            the client application.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Required. The timestamp of the event.
        job_event (google.cloud.talent_v4.types.JobEvent):
            An event issued when a job seeker interacts
            with the application that implements Cloud
            Talent Solution.

            This field is a member of `oneof`_ ``event``.
        event_notes (str):
            Notes about the event provided by recruiters
            or other users, for example, feedback on why a
            job was bookmarked.
    """

    request_id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    event_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=4,
        message=timestamp_pb2.Timestamp,
    )
    job_event: "JobEvent" = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="event",
        message="JobEvent",
    )
    event_notes: str = proto.Field(
        proto.STRING,
        number=9,
    )


class JobEvent(proto.Message):
    r"""An event issued when a job seeker interacts with the
    application that implements Cloud Talent Solution.

    Attributes:
        type_ (google.cloud.talent_v4.types.JobEvent.JobEventType):
            Required. The type of the event (see
            [JobEventType][google.cloud.talent.v4.JobEvent.JobEventType]).
        jobs (MutableSequence[str]):
            Required. The [job name(s)][google.cloud.talent.v4.Job.name]
            associated with this event. For example, if this is an
            [impression][google.cloud.talent.v4.JobEvent.JobEventType.IMPRESSION]
            event, this field contains the identifiers of all jobs shown
            to the job seeker. If this was a
            [view][google.cloud.talent.v4.JobEvent.JobEventType.VIEW]
            event, this field contains the identifier of the viewed job.

            The format is
            "projects/{project_id}/tenants/{tenant_id}/jobs/{job_id}",
            for example, "projects/foo/tenants/bar/jobs/baz".
    """

    class JobEventType(proto.Enum):
        r"""An enumeration of an event attributed to the behavior of the
        end user, such as a job seeker.
        """
        JOB_EVENT_TYPE_UNSPECIFIED = 0
        IMPRESSION = 1
        VIEW = 2
        VIEW_REDIRECT = 3
        APPLICATION_START = 4
        APPLICATION_FINISH = 5
        APPLICATION_QUICK_SUBMISSION = 6
        APPLICATION_REDIRECT = 7
        APPLICATION_START_FROM_SEARCH = 8
        APPLICATION_REDIRECT_FROM_SEARCH = 9
        APPLICATION_COMPANY_SUBMIT = 10
        BOOKMARK = 11
        NOTIFICATION = 12
        HIRED = 13
        SENT_CV = 14
        INTERVIEW_GRANTED = 15

    type_: JobEventType = proto.Field(
        proto.ENUM,
        number=1,
        enum=JobEventType,
    )
    jobs: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.talent import gapic_version as package_version

__version__ = package_version.__version__


from google.cloud.talent_v4.services.company_service.async_client import (
    CompanyServiceAsyncClient,
)
from google.cloud.talent_v4.services.company_service.client import CompanyServiceClient
from google.cloud.talent_v4.services.completion.async_client import (
    CompletionAsyncClient,
)
from google.cloud.talent_v4.services.completion.client import CompletionClient
from google.cloud.talent_v4.services.event_service.async_client import (
    EventServiceAsyncClient,
)
from google.cloud.talent_v4.services.event_service.client import EventServiceClient
from google.cloud.talent_v4.services.job_service.async_client import (
    JobServiceAsyncClient,
)
from google.cloud.talent_v4.services.job_service.client import JobServiceClient
from google.cloud.talent_v4.services.tenant_service.async_client import (
    TenantServiceAsyncClient,
)
from google.cloud.talent_v4.services.tenant_service.client import TenantServiceClient
from google.cloud.talent_v4.types.common import (
    BatchOperationMetadata,
    CommuteMethod,
    CompanySize,
    CompensationInfo,
    CustomAttribute,
    DegreeType,
    DeviceInfo,
    EmploymentType,
    HtmlSanitization,
    JobBenefit,
    JobCategory,
    JobLevel,
    Location,
    PostingRegion,
    RequestMetadata,
    ResponseMetadata,
    SpellingCorrection,
    TimestampRange,
    Visibility,
)
from google.cloud.talent_v4.types.company import Company
from google.cloud.talent_v4.types.company_service import (
    CreateCompanyRequest,
    DeleteCompanyRequest,
    GetCompanyRequest,
    ListCompaniesRequest,
    ListCompaniesResponse,
    UpdateCompanyRequest,
)
from google.cloud.talent_v4.types.completion_service import (
    CompleteQueryRequest,
    CompleteQueryResponse,
)
from google.cloud.talent_v4.types.event import ClientEvent, JobEvent
from google.cloud.talent_v4.types.event_service import CreateClientEventRequest
from google.cloud.talent_v4.types.filters import (
    CommuteFilter,
    CompensationFilter,
    JobQuery,
    LocationFilter,
)
from google.cloud.talent_v4.types.histogram import HistogramQuery, HistogramQueryResult
from google.cloud.talent_v4.types.job import Job
from google.cloud.talent_v4.types.job_service import (
    BatchCreateJobsRequest,
    BatchCreateJobsResponse,
    BatchDeleteJobsRequest,
    BatchDeleteJobsResponse,
    BatchUpdateJobsRequest,
    BatchUpdateJobsResponse,
    CreateJobRequest,
    DeleteJobRequest,
    GetJobRequest,
    JobResult,
    JobView,
    ListJobsRequest,
    ListJobsResponse,
    SearchJobsRequest,
    SearchJobsResponse,
    UpdateJobRequest,
)
from google.cloud.talent_v4.types.tenant import Tenant
from google.cloud.talent_v4.types.tenant_service import (
    CreateTenantRequest,
    DeleteTenantRequest,
    GetTenantRequest,
    ListTenantsRequest,
    ListTenantsResponse,
    UpdateTenantRequest,
)

__all__ = (
    "CompanyServiceClient",
    "CompanyServiceAsyncClient",
    "CompletionClient",
    "CompletionAsyncClient",
    "EventServiceClient",
    "EventServiceAsyncClient",
    "JobServiceClient",
    "JobServiceAsyncClient",
    "TenantServiceClient",
    "TenantServiceAsyncClient",
    "BatchOperationMetadata",
    "CompensationInfo",
    "CustomAttribute",
    "DeviceInfo",
    "Location",
    "RequestMetadata",
    "ResponseMetadata",
    "SpellingCorrection",
    "TimestampRange",
    "CommuteMethod",
    "CompanySize",
    "DegreeType",
    "EmploymentType",
    "HtmlSanitization",
    "JobBenefit",
    "JobCategory",
    "JobLevel",
    "PostingRegion",
    "Visibility",
    "Company",
    "CreateCompanyRequest",
    "DeleteCompanyRequest",
    "GetCompanyRequest",
    "ListCompaniesRequest",
    "ListCompaniesResponse",
    "UpdateCompanyRequest",
    "CompleteQueryRequest",
    "CompleteQueryResponse",
    "ClientEvent",
    "JobEvent",
    "CreateClientEventRequest",
    "CommuteFilter",
    "CompensationFilter",
    "JobQuery",
    "LocationFilter",
    "HistogramQuery",
    "HistogramQueryResult",
    "Job",
    "BatchCreateJobsRequest",
    "BatchCreateJobsResponse",
    "BatchDeleteJobsRequest",
    "BatchDeleteJobsResponse",
    "BatchUpdateJobsRequest",
    "BatchUpdateJobsResponse",
    "CreateJobRequest",
    "DeleteJobRequest",
    "GetJobRequest",
    "JobResult",
    "ListJobsRequest",
    "ListJobsResponse",
    "SearchJobsRequest",
    "SearchJobsResponse",
    "UpdateJobRequest",
    "JobView",
    "Tenant",
    "CreateTenantRequest",
    "DeleteTenantRequest",
    "GetTenantRequest",
    "ListTenantsRequest",
    "ListTenantsResponse",
    "UpdateTenantRequest",
)



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.talent_v4beta1.types import common

__protobuf__ = proto.module(
    package="google.cloud.talent.v4beta1",
    manifest={
        "Job",
    },
)


class Job(proto.Message):
    r"""A Job resource represents a job posting (also referred to as a "job
    listing" or "job requisition"). A job belongs to a
    [Company][google.cloud.talent.v4beta1.Company], which is the hiring
    entity responsible for the job.

    Attributes:
        name (str):
            Required during job update.

            The resource name for the job. This is generated by the
            service when a job is created.

            The format is
            "projects/{project_id}/tenants/{tenant_id}/jobs/{job_id}".
            For example, "projects/foo/tenants/bar/jobs/baz".

            If tenant id is unspecified, the default tenant is used. For
            example, "projects/foo/jobs/bar".

            Use of this field in job queries and API calls is preferred
            over the use of
            [requisition_id][google.cloud.talent.v4beta1.Job.requisition_id]
            since this value is unique.
        company (str):
            Required. The resource name of the company listing the job.

            The format is
            "projects/{project_id}/tenants/{tenant_id}/companies/{company_id}".
            For example, "projects/foo/tenants/bar/companies/baz".

            If tenant id is unspecified, the default tenant is used. For
            example, "projects/foo/companies/bar".
        requisition_id (str):
            Required. The requisition ID, also referred to as the
            posting ID, is assigned by the client to identify a job.
            This field is intended to be used by clients for client
            identification and tracking of postings. A job isn't allowed
            to be created if there is another job with the same
            [company][google.cloud.talent.v4beta1.Job.name],
            [language_code][google.cloud.talent.v4beta1.Job.language_code]
            and
            [requisition_id][google.cloud.talent.v4beta1.Job.requisition_id].

            The maximum number of allowed characters is 255.
        title (str):
            Required. The title of the job, such as
            "Software Engineer"
            The maximum number of allowed characters is 500.
        description (str):
            Required. The description of the job, which typically
            includes a multi-paragraph description of the company and
            related information. Separate fields are provided on the job
            object for
            [responsibilities][google.cloud.talent.v4beta1.Job.responsibilities],
            [qualifications][google.cloud.talent.v4beta1.Job.qualifications],
            and other job characteristics. Use of these separate job
            fields is recommended.

            This field accepts and sanitizes HTML input, and also
            accepts bold, italic, ordered list, and unordered list
            markup tags.

            The maximum number of allowed characters is 100,000.
        addresses (MutableSequence[str]):
            Strongly recommended for the best service experience.

            Location(s) where the employer is looking to hire for this
            job posting.

            Specifying the full street address(es) of the hiring
            location enables better API results, especially job searches
            by commute time.

            At most 50 locations are allowed for best search
            performance. If a job has more locations, it is suggested to
            split it into multiple jobs with unique
            [requisition_id][google.cloud.talent.v4beta1.Job.requisition_id]s
            (e.g. 'ReqA' becomes 'ReqA-1', 'ReqA-2', and so on.) as
            multiple jobs with the same
            [company][google.cloud.talent.v4beta1.Job.company],
            [language_code][google.cloud.talent.v4beta1.Job.language_code]
            and
            [requisition_id][google.cloud.talent.v4beta1.Job.requisition_id]
            are not allowed. If the original
            [requisition_id][google.cloud.talent.v4beta1.Job.requisition_id]
            must be preserved, a custom field should be used for
            storage. It is also suggested to group the locations that
            close to each other in the same job for better search
            experience.

            The maximum number of allowed characters is 500.
        application_info (google.cloud.talent_v4beta1.types.Job.ApplicationInfo):
            Job application information.
        job_benefits (MutableSequence[google.cloud.talent_v4beta1.types.JobBenefit]):
            The benefits included with the job.
        compensation_info (google.cloud.talent_v4beta1.types.CompensationInfo):
            Job compensation information (a.k.a. "pay
            rate") i.e., the compensation that will paid to
            the employee.
        custom_attributes (MutableMapping[str, google.cloud.talent_v4beta1.types.CustomAttribute]):
            A map of fields to hold both filterable and non-filterable
            custom job attributes that are not covered by the provided
            structured fields.

            The keys of the map are strings up to 64 bytes and must
            match the pattern: ``[a-zA-Z][a-zA-Z0-9_]*``. For example,
            key0LikeThis or KEY_1_LIKE_THIS.

            At most 100 filterable and at most 100 unfilterable keys are
            supported. For filterable ``string_values``, across all keys
            at most 200 values are allowed, with each string no more
            than 255 characters. For unfilterable ``string_values``, the
            maximum total size of ``string_values`` across all keys is
            50KB.
        degree_types (MutableSequence[google.cloud.talent_v4beta1.types.DegreeType]):
            The desired education degrees for the job,
            such as Bachelors, Masters.
        department (str):
            The department or functional area within the
            company with the open position.

            The maximum number of allowed characters is 255.
        employment_types (MutableSequence[google.cloud.talent_v4beta1.types.EmploymentType]):
            The employment type(s) of a job, for example, [full
            time][google.cloud.talent.v4beta1.EmploymentType.FULL_TIME]
            or [part
            time][google.cloud.talent.v4beta1.EmploymentType.PART_TIME].
        incentives (str):
            A description of bonus, commission, and other
            compensation incentives associated with the job
            not including salary or pay.
            The maximum number of allowed characters is
            10,000.
        language_code (str):
            The language of the posting. This field is distinct from any
            requirements for fluency that are associated with the job.

            Language codes must be in BCP-47 format, such as "en-US" or
            "sr-Latn". For more information, see `Tags for Identifying
            Languages <https://tools.ietf.org/html/bcp47>`__\ {:
            class="external" target="_blank" }.

            If this field is unspecified and
            [Job.description][google.cloud.talent.v4beta1.Job.description]
            is present, detected language code based on
            [Job.description][google.cloud.talent.v4beta1.Job.description]
            is assigned, otherwise defaults to 'en_US'.
        job_level (google.cloud.talent_v4beta1.types.JobLevel):
            The experience level associated with the job,
            such as "Entry Level".
        promotion_value (int):
            A promotion value of the job, as determined by the client.
            The value determines the sort order of the jobs returned
            when searching for jobs using the featured jobs search call,
            with higher promotional values being returned first and ties
            being resolved by relevance sort. Only the jobs with a
            promotionValue >0 are returned in a FEATURED_JOB_SEARCH.

            Default value is 0, and negative values are treated as 0.
        qualifications (str):
            A description of the qualifications required to perform the
            job. The use of this field is recommended as an alternative
            to using the more general
            [description][google.cloud.talent.v4beta1.Job.description]
            field.

            This field accepts and sanitizes HTML input, and also
            accepts bold, italic, ordered list, and unordered list
            markup tags.

            The maximum number of allowed characters is 10,000.
        responsibilities (str):
            A description of job responsibilities. The use of this field
            is recommended as an alternative to using the more general
            [description][google.cloud.talent.v4beta1.Job.description]
            field.

            This field accepts and sanitizes HTML input, and also
            accepts bold, italic, ordered list, and unordered list
            markup tags.

            The maximum number of allowed characters is 10,000.
        posting_region (google.cloud.talent_v4beta1.types.PostingRegion):
            The job
            [PostingRegion][google.cloud.talent.v4beta1.PostingRegion]
            (for example, state, country) throughout which the job is
            available. If this field is set, a
            [LocationFilter][google.cloud.talent.v4beta1.LocationFilter]
            in a search query within the job region finds this job
            posting if an exact location match isn't specified. If this
            field is set to
            [PostingRegion.NATION][google.cloud.talent.v4beta1.PostingRegion.NATION]
            or
            [PostingRegion.ADMINISTRATIVE_AREA][google.cloud.talent.v4beta1.PostingRegion.ADMINISTRATIVE_AREA],
            setting job
            [Job.addresses][google.cloud.talent.v4beta1.Job.addresses]
            to the same location level as this field is strongly
            recommended.
        visibility (google.cloud.talent_v4beta1.types.Visibility):
            Deprecated. The job is only visible to the owner.

            The visibility of the job.

            Defaults to
            [Visibility.ACCOUNT_ONLY][google.cloud.talent.v4beta1.Visibility.ACCOUNT_ONLY]
            if not specified.
        job_start_time (google.protobuf.timestamp_pb2.Timestamp):
            The start timestamp of the job in UTC time
            zone. Typically this field is used for
            contracting engagements. Invalid timestamps are
            ignored.
        job_end_time (google.protobuf.timestamp_pb2.Timestamp):
            The end timestamp of the job. Typically this
            field is used for contracting engagements.
            Invalid timestamps are ignored.
        posting_publish_time (google.protobuf.timestamp_pb2.Timestamp):
            The timestamp this job posting was most
            recently published. The default value is the
            time the request arrives at the server. Invalid
            timestamps are ignored.
        posting_expire_time (google.protobuf.timestamp_pb2.Timestamp):
            Strongly recommended for the best service experience.

            The expiration timestamp of the job. After this timestamp,
            the job is marked as expired, and it no longer appears in
            search results. The expired job can't be listed by the
            [ListJobs][google.cloud.talent.v4beta1.JobService.ListJobs]
            API, but it can be retrieved with the
            [GetJob][google.cloud.talent.v4beta1.JobService.GetJob] API
            or updated with the
            [UpdateJob][google.cloud.talent.v4beta1.JobService.UpdateJob]
            API or deleted with the
            [DeleteJob][google.cloud.talent.v4beta1.JobService.DeleteJob]
            API. An expired job can be updated and opened again by using
            a future expiration timestamp. Updating an expired job fails
            if there is another existing open job with same
            [company][google.cloud.talent.v4beta1.Job.company],
            [language_code][google.cloud.talent.v4beta1.Job.language_code]
            and
            [requisition_id][google.cloud.talent.v4beta1.Job.requisition_id].

            The expired jobs are retained in our system for 90 days.
            However, the overall expired job count cannot exceed 3 times
            the maximum number of open jobs over previous 7 days. If
            this threshold is exceeded, expired jobs are cleaned out in
            order of earliest expire time. Expired jobs are no longer
            accessible after they are cleaned out.

            Invalid timestamps are ignored, and treated as expire time
            not provided.

            If the timestamp is before the instant request is made, the
            job is treated as expired immediately on creation. This kind
            of job can not be updated. And when creating a job with past
            timestamp, the
            [posting_publish_time][google.cloud.talent.v4beta1.Job.posting_publish_time]
            must be set before
            [posting_expire_time][google.cloud.talent.v4beta1.Job.posting_expire_time].
            The purpose of this feature is to allow other objects, such
            as [Application][google.cloud.talent.v4beta1.Application],
            to refer a job that didn't exist in the system prior to
            becoming expired. If you want to modify a job that was
            expired on creation, delete it and create a new one.

            If this value isn't provided at the time of job creation or
            is invalid, the job posting expires after 30 days from the
            job's creation time. For example, if the job was created on
            2017/01/01 13:00AM UTC with an unspecified expiration date,
            the job expires after 2017/01/31 13:00AM UTC.

            If this value isn't provided on job update, it depends on
            the field masks set by
            [UpdateJobRequest.update_mask][google.cloud.talent.v4beta1.UpdateJobRequest.update_mask].
            If the field masks include
            [job_end_time][google.cloud.talent.v4beta1.Job.job_end_time],
            or the masks are empty meaning that every field is updated,
            the job posting expires after 30 days from the job's last
            update time. Otherwise the expiration date isn't updated.
        posting_create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The timestamp when this job
            posting was created.
        posting_update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The timestamp when this job
            posting was last updated.
        company_display_name (str):
            Output only. Display name of the company
            listing the job.
        derived_info (google.cloud.talent_v4beta1.types.Job.DerivedInfo):
            Output only. Derived details about the job
            posting.
        processing_options (google.cloud.talent_v4beta1.types.Job.ProcessingOptions):
            Options for job processing.
    """

    class ApplicationInfo(proto.Message):
        r"""Application related details of a job posting.

        Attributes:
            emails (MutableSequence[str]):
                Use this field to specify email address(es)
                to which resumes or applications can be sent.
                The maximum number of allowed characters for
                each entry is 255.
            instruction (str):
                Use this field to provide instructions, such
                as "Mail your application to ...", that a
                candidate can follow to apply for the job.
                This field accepts and sanitizes HTML input, and
                also accepts bold, italic, ordered list, and
                unordered list markup tags.
                The maximum number of allowed characters is
                3,000.
            uris (MutableSequence[str]):
                Use this URI field to direct an applicant to
                a website, for example to link to an online
                application form.
                The maximum number of allowed characters for
                each entry is 2,000.
        """

        emails: MutableSequence[str] = proto.RepeatedField(
            proto.STRING,
            number=1,
        )
        instruction: str = proto.Field(
            proto.STRING,
            number=2,
        )
        uris: MutableSequence[str] = proto.RepeatedField(
            proto.STRING,
            number=3,
        )

    class DerivedInfo(proto.Message):
        r"""Derived details about the job posting.

        Attributes:
            locations (MutableSequence[google.cloud.talent_v4beta1.types.Location]):
                Structured locations of the job, resolved from
                [Job.addresses][google.cloud.talent.v4beta1.Job.addresses].

                [locations][google.cloud.talent.v4beta1.Job.DerivedInfo.locations]
                are exactly matched to
                [Job.addresses][google.cloud.talent.v4beta1.Job.addresses]
                in the same order.
            job_categories (MutableSequence[google.cloud.talent_v4beta1.types.JobCategory]):
                Job categories derived from
                [Job.title][google.cloud.talent.v4beta1.Job.title] and
                [Job.description][google.cloud.talent.v4beta1.Job.description].
        """

        locations: MutableSequence[common.Location] = proto.RepeatedField(
            proto.MESSAGE,
            number=1,
            message=common.Location,
        )
        job_categories: MutableSequence[common.JobCategory] = proto.RepeatedField(
            proto.ENUM,
            number=3,
            enum=common.JobCategory,
        )

    class ProcessingOptions(proto.Message):
        r"""Options for job processing.

        Attributes:
            disable_street_address_resolution (bool):
                If set to ``true``, the service does not attempt to resolve
                a more precise address for the job.
            html_sanitization (google.cloud.talent_v4beta1.types.HtmlSanitization):
                Option for job HTML content sanitization. Applied fields
                are:

                -  description
                -  applicationInfo.instruction
                -  incentives
                -  qualifications
                -  responsibilities

                HTML tags in these fields may be stripped if sanitiazation
                isn't disabled.

                Defaults to
                [HtmlSanitization.SIMPLE_FORMATTING_ONLY][google.cloud.talent.v4beta1.HtmlSanitization.SIMPLE_FORMATTING_ONLY].
        """

        disable_street_address_resolution: bool = proto.Field(
            proto.BOOL,
            number=1,
        )
        html_sanitization: common.HtmlSanitization = proto.Field(
            proto.ENUM,
            number=2,
            enum=common.HtmlSanitization,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    company: str = proto.Field(
        proto.STRING,
        number=2,
    )
    requisition_id: str = proto.Field(
        proto.STRING,
        number=3,
    )
    title: str = proto.Field(
        proto.STRING,
        number=4,
    )
    description: str = proto.Field(
        proto.STRING,
        number=5,
    )
    addresses: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=6,
    )
    application_info: ApplicationInfo = proto.Field(
        proto.MESSAGE,
        number=7,
        message=ApplicationInfo,
    )
    job_benefits: MutableSequence[common.JobBenefit] = proto.RepeatedField(
        proto.ENUM,
        number=8,
        enum=common.JobBenefit,
    )
    compensation_info: common.CompensationInfo = proto.Field(
        proto.MESSAGE,
        number=9,
        message=common.CompensationInfo,
    )
    custom_attributes: MutableMapping[str, common.CustomAttribute] = proto.MapField(
        proto.STRING,
        proto.MESSAGE,
        number=10,
        message=common.CustomAttribute,
    )
    degree_types: MutableSequence[common.DegreeType] = proto.RepeatedField(
        proto.ENUM,
        number=11,
        enum=common.DegreeType,
    )
    department: str = proto.Field(
        proto.STRING,
        number=12,
    )
    employment_types: MutableSequence[common.EmploymentType] = proto.RepeatedField(
        proto.ENUM,
        number=13,
        enum=common.EmploymentType,
    )
    incentives: str = proto.Field(
        proto.STRING,
        number=14,
    )
    language_code: str = proto.Field(
        proto.STRING,
        number=15,
    )
    job_level: common.JobLevel = proto.Field(
        proto.ENUM,
        number=16,
        enum=common.JobLevel,
    )
    promotion_value: int = proto.Field(
        proto.INT32,
        number=17,
    )
    qualifications: str = proto.Field(
        proto.STRING,
        number=18,
    )
    responsibilities: str = proto.Field(
        proto.STRING,
        number=19,
    )
    posting_region: common.PostingRegion = proto.Field(
        proto.ENUM,
        number=20,
        enum=common.PostingRegion,
    )
    visibility: common.Visibility = proto.Field(
        proto.ENUM,
        number=21,
        enum=common.Visibility,
    )
    job_start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=22,
        message=timestamp_pb2.Timestamp,
    )
    job_end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=23,
        message=timestamp_pb2.Timestamp,
    )
    posting_publish_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=24,
        message=timestamp_pb2.Timestamp,
    )
    posting_expire_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=25,
        message=timestamp_pb2.Timestamp,
    )
    posting_create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=26,
        message=timestamp_pb2.Timestamp,
    )
    posting_update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=27,
        message=timestamp_pb2.Timestamp,
    )
    company_display_name: str = proto.Field(
        proto.STRING,
        number=28,
    )
    derived_info: DerivedInfo = proto.Field(
        proto.MESSAGE,
        number=29,
        message=DerivedInfo,
    )
    processing_options: ProcessingOptions = proto.Field(
        proto.MESSAGE,
        number=30,
        message=ProcessingOptions,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
